window.Gleam.initSearch([{"doc":"tobble","title":"tobble","content":"# tobble\n\n[![Package Version](https://img.shields.io/hexpm/v/tobble)](https://hex.pm/packages/tobble)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/tobble/)\n\nTobble is a table library for Gleam, which makes it as easy as\npossible to render tables from simple output. It does provide some\ncustomization options, but they are not very expansive, as Tobble does not\naim to be a full layout library. Rather, it aims to make it simple to make\nbeautiful output for your programs.\n\n```gleam\nimport gleam/io\nimport tobble\n\npub fn main() {\n  let assert Ok(table) =\n    tobble.builder()\n    |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n    |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n    |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n    |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n    |&gt; tobble.build()\n\n  io.println(tobble.render(table))\n}\n```\n\n```text\n+---------+--------------+\n|         | Output       |\n+---------+--------------+\n| Stage 1 | Wibble       |\n| Stage 2 | Wobble       |\n| Stage 3 | WibbleWobble |\n+---------+--------------+\n```\n\n## Installation\n\n```sh\ngleam add tobble@1\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/tobble&gt;.\n\n## Development\n\nTobble is built using Gleam 1.6. If you would like to hack on Tobble, you\ncan run the tests with `gleam test`.\n","url":"index.html"},{"doc":"tobble","title":"Builder","content":"pub opaque type Builder\n `Builder` is a type used to help you build tables. See `builder()` for more details.\n\nSynonyms:\ntobble.Builder\ntobble Builder","url":"tobble.html#Builder"},{"doc":"tobble","title":"BuilderError","content":"pub type BuilderError {\n  InconsistentColumnCountError(expected: Int, got: Int)\n  EmptyTableError\n}\n\nInconsistentColumnCountError(expected: Int, got: Int)\n Returned when not all rows have the same number of columns.\n\n **Why is this an error?** It is not possible to render a rectangular\n                           table if any row has a different number of columns than another.\n\nEmptyTableError\n Returned when attempting to build a table with no rows.\n\n **Why is this an error?** It is somewhat unclear how to render this, and\n                           is left as an error so callers can handle it\n                           however is best for their application.\n\nSynonyms:\ntobble.BuilderError\ntobble BuilderError","url":"tobble.html#BuilderError"},{"doc":"tobble","title":"RenderLineType","content":"pub type RenderLineType {\n  BoxDrawingCharsLineType\n  BoxDrawingCharsWithRoundedCornersLineType\n  ASCIILineType\n}\n\nBoxDrawingCharsLineType\n Renders the table with box drawing characters for the borders.\n\n &lt;pre&gt;&lt;code style=&quot;font-family: monospace;&quot; class=&quot;language-plaintext&quot;&gt;┌─────────┬──────────────┐\n │         │ Output       │\n ├─────────┼──────────────┤\n │ Stage 1 │ Wibble       │\n │ Stage 2 │ Wobble       │\n │ Stage 3 │ WibbleWobble │\n └─────────┴──────────────┘&lt;/code&gt;&lt;/pre&gt;\n\nBoxDrawingCharsWithRoundedCornersLineType\n Renders the table with box drawing characters for the borders, but\n with rounded corners.\n\n &lt;pre&gt;&lt;code style=&quot;font-family: monospace;&quot; class=&quot;language-plaintext&quot;&gt;╭─────────┬──────────────╮\n │         │ Output       │\n ├─────────┼──────────────┤\n │ Stage 1 │ Wibble       │\n │ Stage 2 │ Wobble       │\n │ Stage 3 │ WibbleWobble │\n ╰─────────┴──────────────╯&lt;/code&gt;&lt;/pre&gt;\n\nASCIILineType\n Render the table with ASCII characters for the borders.\n This is the default setting.\n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \n\nSynonyms:\ntobble.RenderLineType\ntobble RenderLineType","url":"tobble.html#RenderLineType"},{"doc":"tobble","title":"RenderOption","content":"pub type RenderOption {\n  TableWidthRenderOption(width: Int)\n  ColumnWidthRenderOption(width: Int)\n  LineTypeRenderOption(line_type: RenderLineType)\n}\n\nTableWidthRenderOption(width: Int)\n Render the table with a width of, at most, the given width. Note that this\n is best effort, and there are pathological cases where Tobble will decide\n to render your tables slightly wider than requested (e.g. requesting a\n width too small to even fit the table borders). By default, the table\n width is unconstrained.\n\nColumnWidthRenderOption(width: Int)\n Render the table where each column&#39;s text has the given width. If a width\n less than 1 is given, this will default to 1. By default, columns are as\n wide as the longest row within them.\n\nLineTypeRenderOption(line_type: RenderLineType)\n Render the table with a different style of border\n By default, `ASCIILineType` is used.\n\nSynonyms:\ntobble.RenderOption\ntobble RenderOption","url":"tobble.html#RenderOption"},{"doc":"tobble","title":"Table","content":"pub opaque type Table\n `Table` is the central type of Tobble. It holds the data you wish to display,\n without regard for how you render it. These can be built using `builder`/`build`.\n\nSynonyms:\ntobble.Table\ntobble Table","url":"tobble.html#Table"},{"doc":"tobble","title":"add_row","content":"pub fn add_row(\n  to builder: Builder,\n  columns columns: List(String),\n) -&gt; Builder\n Add a row to a table that is being built. Every call to `add_row` for a given\n `Builder` must have the same number of columns, or an\n `InconsistentColumnCountError` will be returned when `build` is called.\nSynonyms:\ntobble.add_row\ntobble add_row","url":"tobble.html#add_row"},{"doc":"tobble","title":"build","content":"pub fn build(\n  with builder: Builder,\n) -&gt; Result(Table, BuilderError)\n Build a `Table` from the given `Builder`. If an invalid operation was\n performed when constructing the `Builder`, an error will be returned.\nSynonyms:\ntobble.build\ntobble build","url":"tobble.html#build"},{"doc":"tobble","title":"builder","content":"pub fn builder() -&gt; Builder\n Create a new `Builder` for table generation. Once you have completed\n adding your rows to this with `add_row`, you should call `build` to\n generate a `Table`.\nSynonyms:\ntobble.builder\ntobble builder","url":"tobble.html#builder"},{"doc":"tobble","title":"render","content":"pub fn render(table table: Table) -&gt; String\n Render the given table to a `String`, with the default options.\n The output can be customized by using `render_with_options`.\n\n # Example\n\n \n let assert Ok(ttable) =\n     tobble.builder()\n     |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n     |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n     |&gt; tobble.build()\n\n   io.println(tobble.render(table))\n \n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble.render\ntobble render","url":"tobble.html#render"},{"doc":"tobble","title":"render_iter","content":"pub fn render_iter(\n  table table: Table,\n  options options: List(RenderOption),\n) -&gt; Yielder(String)\n Render the given table to a `Yielder`. Each element of the `Yielder` will\n produce a single line of output, without a trailing newline. Note that\n options are applied in order, so if duplicate or conflicting options\n are given, the last one will win.\n\n # Example\n\n \n let assert Ok(table) =\n tobble.builder()\n |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n |&gt; tobble.build()\n\n\n table\n |&gt; tobble.render_iter(options: [])\n |&gt; yielder.each(io.println)\n \n\n text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n \nSynonyms:\ntobble.render_iter\ntobble render_iter","url":"tobble.html#render_iter"},{"doc":"tobble","title":"render_with_options","content":"pub fn render_with_options(\n  table table: Table,\n  options options: List(RenderOption),\n) -&gt; String\n Render the given table to a `String`, with extra options. Note that options\n are applied in order, so if duplicate or conflicting options are given, the\n last one will win.\n\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n io.println(\n   tobble.render_with_options(table, options: [\n     tobble.ColumnWidthRenderOption(6),\n   ]),\n )\n \n\n text\n +--------+--------+\n |        | Output |\n +--------+--------+\n | Stage  | Wibble |\n | 1      |        |\n | Stage  | Wobble |\n | 2      |        |\n | Stage  | Wibble |\n | 3      | Wobble |\n +--------+--------+\n \nSynonyms:\ntobble.render_with_options\ntobble render_with_options","url":"tobble.html#render_with_options"},{"doc":"tobble","title":"to_list","content":"pub fn to_list(table: Table) -&gt; List(List(String))\n Convert an existing table to a list of its rows.\n\n # Example\n\n \n let assert Ok(table) =\n   tobble.builder()\n   |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n   |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n   |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n   |&gt; tobble.build()\n\n io.debug(tobble.to_list(table))\n \n\n \n [\n   [&quot;&quot;, &quot;Output&quot;],\n   [&quot;Stage 1&quot;, &quot;Wibble&quot;],\n   [&quot;Stage 2&quot;, &quot;Wobble&quot;],\n   [&quot;Stage 3&quot;, &quot;WibbleWobble&quot;]\n ]\n \nSynonyms:\ntobble.to_list\ntobble to_list","url":"tobble.html#to_list"},{"doc":"tobble","title":"tobble","content":" Tobble is a table library for Gleam, which makes it as easy as\n possible to render tables from simple output. It does provide some\n customization options, but they are not very expansive, as Tobble does not\n aim to be a full layout library. Rather, it aims to make it simple to make\n beautiful output for your programs.\n\n ```gleam\n import gleam/io\n import tobble\n\n pub fn main() {\n   let assert Ok(table) =\n     tobble.builder()\n     |&gt; tobble.add_row([&quot;&quot;, &quot;Output&quot;])\n     |&gt; tobble.add_row([&quot;Stage 1&quot;, &quot;Wibble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 2&quot;, &quot;Wobble&quot;])\n     |&gt; tobble.add_row([&quot;Stage 3&quot;, &quot;WibbleWobble&quot;])\n     |&gt; tobble.build()\n\n   io.println(tobble.render(table))\n }\n ```\n\n ```text\n +---------+--------------+\n |         | Output       |\n +---------+--------------+\n | Stage 1 | Wibble       |\n | Stage 2 | Wobble       |\n | Stage 3 | WibbleWobble |\n +---------+--------------+\n ```","url":"tobble.html"}]);